@@ -7,7 +7,7 @@ from itertools import combinations
 def class_for_name(module_name, class_name) -> object:
     """Returns a class for a given module and class name.
 
-    Parameters:
+    Args:
         module_name (str): The name of the module.
         class_name (str): The name of the class.
 
@@ -28,11 +28,14 @@ def class_for_name(module_name, class_name) -> object:
 
 def get_Xy_from_df(df, target_column) -> tuple:
     """Get X and y from a dataframe.
-    Parameters:
+
+    Args:
         df (pandas.DataFrame): The input dataframe.
         target_column (str): The name of the target column.
+
     Returns:
         tuple: The tuple (X, y).
+
     Examples:
         >>> from spotPython.utils.convert import get_Xy_from_df
         >>> import pandas as pd
@@ -41,6 +44,9 @@ def get_Xy_from_df(df, target_column) -> tuple:
     """
     X = df.drop(columns=[target_column])
     y = df[target_column]
+    # convert to numpy arrays
+    X = X.to_numpy()
+    y = y.to_numpy()
     return X, y
 
 
@@ -56,8 +62,10 @@ def series_to_array(series):
     """Converts a pandas series to a numpy array.
     Args:
         series (pandas.Series): The input series.
+
     Returns:
         (numpy.ndarray): The output array.
+
     Examples:
         >>> from spotPython.utils.convert import series_to_array
         >>> import pandas as pd
@@ -78,8 +86,10 @@ def add_logical_columns(X, arity=2, operations=["and", "or", "xor"]):
         X (pd.DataFrame): dataframe with features
         arity (int): the number of columns to combine at once
         operations (list of str): the operations to apply. Possible values are 'and', 'or' and 'xor'
+
     Returns:
         X (pd.DataFrame): dataframe with new features
+
     Examples:
         >>> X = pd.DataFrame({"a": [True, False, True], "b": [True, True, False], "c": [False, False, True]})
         >>> add_logical_columns(X)
@@ -105,3 +115,27 @@ def add_logical_columns(X, arity=2, operations=["and", "or", "xor"]):
     # Join all the new columns at once
     X = pd.concat([X] + new_cols, axis=1)
     return X
+
+
+def map_to_True_False(value):
+    """
+    Map the string value to a boolean value.
+    If the value is "True" or "true", return True.
+    Otherwise, return False.
+
+    Args:
+        value (str):
+            The string to be mapped to a boolean value.
+    Returns:
+        bool:
+            True if the value is "True" or "true", False otherwise.
+
+    Examples:
+    >>> from spotPython.utils.convert import map_to_True_False
+        map_to_True_False("True")
+        True
+    """
+    if value.lower() == "true":
+        return True
+    else:
+        return False
